@@ -1,6 +1,7 @@
 
 package Apache2::ASP;
 
+our $VERSION = 1.01;
 
 use strict;
 use warnings 'all';
@@ -16,9 +17,8 @@ use Apache2::Directive ();
 use Apache2::Connection ();
 use Apache2::SubRequest ();
 use Apache2::RequestUtil ();
+use Devel::StackTrace;
 
-use vars '$VERSION';
-$VERSION = '1.56_2';
 
 #==============================================================================
 sub handler : method
@@ -27,38 +27,28 @@ sub handler : method
   
   # We function best as an object:
   my $s = $class->SUPER::new( $ENV{APACHE2_ASP_CONFIG} );
-  $main::_ASP::ASP = $s;
-  $s->{r} = $r;
   
   # What Apache2::ASP::Handler is going to handle this request?
-  if( uc($ENV{REQUEST_METHOD}) eq 'POST'  )
+  my $handler_class = $s->resolve_request_handler( $r->uri );
+  if( $handler_class->isa('Apache2::ASP::UploadHandler') )
   {
-    my $handler_class = $s->resolve_request_handler( $r->uri );
-    if( $handler_class->isa('Apache2::ASP::UploadHandler') )
-    {
-      # We use the upload_hook functionality from Apache::Request
-      # to process uploads:
-      my $hook_obj = Apache2::ASP::UploadHook->new(
-        asp           => $s,
-        handler_class => $handler_class,
-      );
-      $s->{'q'} = Apache2::ASP::CGI->new( $r, sub { $hook_obj->hook( @_ ) } );
-    }
-    else
-    {
-      # Not an upload - normal CGI functionality will work fine:
-      $s->{'q'} = Apache2::ASP::CGI->new( $r );
-    }# end if()
+    # We use the upload_hook functionality from Apache::Request
+    # to process uploads:
+    my $hook_obj = Apache2::ASP::UploadHook->new(
+      asp           => $s,
+      handler_class => $handler_class,
+    );
+    $s->{q} = Apache2::ASP::CGI->new( $r, sub { $hook_obj->hook( @_ ) } );
   }
   else
   {
     # Not an upload - normal CGI functionality will work fine:
-    $s->{'q'} = Apache2::ASP::CGI->new( $r );
+    $s->{q} = Apache2::ASP::CGI->new( $r );
   }# end if()
   
   # Get our subref and execute it:
-  $s->setup_request( $r, $s->{'q'} );
-  my $status = eval { $s->execute() };
+  my $handler = $s->setup_request( $r, $s->{q} );
+  my $status = eval { $handler->( ) };
   if( $@ )
   {
     warn "ERROR AFTER CALLING \$handler->( ): $@";
@@ -66,7 +56,7 @@ sub handler : method
   }# end if()
   
   # 0 = OK, everything else means errors of some kind:
-  return $status eq '200' ? 0 : $status;
+  return $status;
 }# end handler()
 
 
@@ -75,9 +65,10 @@ sub _handle_error
 {
   my ($s, $err) = @_;
   
-  warn $err;
+  my $stack = Devel::StackTrace->new;
+  warn "$@ -- " . $stack->as_string;
   $s->response->Clear();
-  $s->global_asa->can('Script_OnError')->( $err );
+  $s->global_asa->can('Script_OnError')->( $stack );
   
   return 500;
 }# end _handle_error()
@@ -136,7 +127,7 @@ Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Apache2-ASP> to submit bug rep
 
 =head1 HOMEPAGE
 
-Please visit the Apache2::ASP homepage at L<http://www.devstack.com/> to see examples
+Please visit the Apache2::ASP homepage at L<http://apache2-asp.no-ip.org/> to see examples
 of Apache2::ASP in action.
 
 =head1 AUTHOR
